import {Component, OnInit} from '@angular/core';
import {ActivatedRoute} from '@angular/router';
import {Api} from '../../service/api';
import {AlertController} from '@ionic/angular';
import {DatePipe} from '@angular/common';

@Component({
    selector: 'v-env-alarm-detail',
    templateUrl: './env-alarm-detail.page.html',
    styleUrls: ['./env-alarm-detail.page.scss'],
})
export class EnvAlarmDetailPage implements OnInit {

    displayArea = 'trouble';
    isTroubleDis = false;
    isAlarmDis = false;
    fieldRegionNo = '';
    fieldRegionName = '';
    fieldRegionGroup = '';

    detailInfo: any = {};
    detailInfoLength = 0;
    disposeState = '';
    fieldDeviceType = '';
    startTime = null;
    stopTime = null;
    curInterval = 12;

    page = 0;
    rows = 10;
    displayLength = 0;

    // 工作模式
    workModeSetting = {
        'workMode': '风机',
        'DeviceNo': '',
        'workModeOld': '1'
    };

    infiniteScroll = document.getElementById('infinite-scroll');

    constructor(private ac: ActivatedRoute, private api: Api,
                private alterContoller: AlertController, private datePipe: DatePipe) {
    }

    ngOnInit() {
        this.init();
    }

    init() {
        this.ac.queryParams.subscribe((data) => {
            this.fieldRegionNo = data.no;
            this.displayArea = data.displayArea;
            this.curInterval = data.interval;

            this.setDateInterval(this.curInterval);
            this.showArea(data.displayArea);

            this.getData();
        });
    }

    getData() {
        this.infiniteScroll.addEventListener('ionInfinite', async function () {
            if (this.displayLength < this.detailInfoLength) {
                console.log('Loading data...');
                await this.wait(500);
                this.infiniteScroll.complete();
                this.appendPage();
                console.log('Done');
            } else {
                console.log('No More Data');
                this.infiniteScroll.disabled = true;
            }
        });
    }

    appendPage() {
        this.page = this.page + 1;

        this.getTroubleList();
        this.getAlarmList();
    }

    appendItems() {
        const originalLength = length;
        for (let i = 0; i < 10; i++) {
            const el = document.createElement('div');
            el.innerHTML = `
              <div class="title">
                <div><img [src]="'../../assets/img/' + item.fieldDeviceType + '.png'" class="deviceIcon"></div>
                <p style="font-size: 14px">{{item.troubleTime}}</p>
              </div>
              <div class="body">
                <h3 style="margin-bottom: 5px;">{{item.description}}</h3>
                <div>
                  <div style="width:65%; float: left">
                    <div *ngIf="item.data !== null && item.data.temp !== undefined && item.data.temp !== null && item.data.temp !== ''"
                    class="warnContent">温度: {{item.data.temp}} ℃</div>
                    <div *ngIf="item.data !== null && item.data.humi !== undefined && item.data.humi !== null && item.data.humi !== ''"
                    class="warnContent">湿度: {{item.data.humi}} %</div>
                    <div *ngIf="item.data !== null && item.data.heatStressLevel !== undefined && item.data.heatStressLevel !== null && item.data.heatStressLevel !== ''"
                    class="warnContent">热应激等级: {{item.data.heatStressLevel}}</div>
                    <div *ngIf="item.data !== null && item.data.liquidPump !== undefined && item.data.liquidPump !== null  && item.data.liquidPump !== ''"
                    class="warnContent">供液泵压力: {{item.data.liquidPump}} MPa</div>
                    <div *ngIf="item.data !== null && item.data.press !== undefined && item.data.press !== null && item.data.press !== ''"
                    class="warnContent">电磁阀压力: {{item.data.press}} MPa</div>
                    <div *ngIf="item.data !== null && item.data.NH3 !== undefined && item.data.NH3 !== null && item.data.NH3 !== ''"
                    class="warnContent">氨气: {{item.data.NH3}} ppm</div>
                  </div>
                  <div style="width:35%; float: left">
                    <div *ngIf="displayArea === 'trouble' && item.disposeState === 0" >
                      <ion-button color="secondary" style="display: inline-block; width: 55px; height: 30px; font-size: 12px; border-radius: 20px;"
                      (click)="onRecvClick(item)">确认修复</ion-button>
                    </div>
                    <img *ngIf="displayArea === 'trouble' && item.disposeState === 1"
                    [src]="'../../assets/img/troubleDisposeState' + item.disposeState + '.png'" class="warnIcon">

                    <img *ngIf="displayArea === 'alarm'"
                    [src]="'../../assets/img/disposeState' + item.disposeState + '.png'" class="warnIcon">
                  </div>
                </div>

              </div>
            `;
            list.appendChild(el);
            length++;
        }
    }

    setDateInterval(interval) {
        this.startTime = this.datePipe.transform(this.getStartTime(interval), 'yyyy-MM');
        this.stopTime = this.datePipe.transform(new Date(), 'yyyy-MM');
    }

    showArea(displayArea) {
        this.isTroubleDis = displayArea === 'trouble' ? true : false;
        this.isAlarmDis = displayArea === 'alarm' ? true : false;
    }

    getTroubleList() {
        if (this.displayArea === 'trouble') {
            this.isTroubleDis = true;
            this.detailInfo = {};
            const req = {
                fieldRegionNo: this.fieldRegionNo,
                startTime: this.parseTime(this.startTime, 'start'),
                stopTime: this.parseTime(this.stopTime, 'stop'),
                disposeState: '',
                fieldDeviceType: ''
            };
            if (this.disposeState !== null && this.disposeState !== '' && this.disposeState !== '全部') {
                req.disposeState = this.disposeState;
            }
            if (this.fieldDeviceType !== null && this.fieldDeviceType !== '' && this.fieldDeviceType !== '全部') {
                req.fieldDeviceType = this.fieldDeviceType;
            }
            this.api.troubleLog.getByTerm(this.page, this.rows, [req, (data) => {
                this.detailInfo = data;
                // if (data.trouble && data.trouble.constructor === Array) {
                //     data.trouble.forEach((value) => {
                //         value.troubleTime = this.api.formatTime('yyyy-MM-dd hh:mm:ss', new Date(value.troubleTime));
                //     });
                //     this.setTrouble(data);
                // }
                this.appendItems();

            }]);
        }
    }

    getAlarmList() {
        if (this.displayArea === 'alarm') {
            this.isAlarmDis = true;
            this.detailInfo = {};
            const req = {
                fieldRegionNo: this.fieldRegionNo,
                startTime: this.parseTime(this.startTime, 'start'),
                stopTime: this.parseTime(this.stopTime, 'stop'),
                disposeState: '',
                fieldDeviceType: ''
            };
            if (this.disposeState !== null && this.disposeState !== '' && this.disposeState !== '全部') {
                req.disposeState = this.disposeState;
            }
            if (this.fieldDeviceType !== null && this.fieldDeviceType !== '' && this.fieldDeviceType !== '全部') {
                req.fieldDeviceType = this.fieldDeviceType;
            }
            this.api.alarm.getCowshedAlarm(this.page, this.rows, [req, (data) => {
                this.detailInfo = data;
                if (data.trouble && data.trouble.constructor === Array) {
                    data.trouble.forEach((value) => {
                        value.troubleTime = this.api.formatTime('yyyy-MM-dd hh:mm:ss', new Date(value.alarmTime));
                    });
                    this.setTrouble(data);
                }
            }]);
        }
    }

    setTrouble(data) {
        if (data && data.trouble && data.trouble.constructor === Array) {
            data.trouble.forEach(item => {
                item.data = JSON.parse(item.data);
            });
        }
        this.detailInfo.trouble = data.trouble;
        this.detailInfoLength = data.trouble.length;
    }
        ionViewWillLeave() {
        // clearInterval(this.commTmr);
    }

    segmentChanged(ev: any) {
        this.disposeState = '';
        this.fieldDeviceType = '';
        if (ev.target.value === 'alarm') {
            this.displayArea = 'alarm';
            this.getAlarmList();
        } else {
            this.displayArea = 'trouble';
            this.getTroubleList();
        }
    }

    // 确认修复
    async onRecvClick(alarm) {
        console.log(alarm);

        const alert = await this.alterContoller.create({
            header: '请注意',
            message: '请确认该故障是否为真实故障?',
            mode: 'ios',
            buttons: [
                {
                    text: '取消',
                    role: 'cancel',
                    cssClass: 'secondary',
                    // cssClass: 'width: 30%',
                }, {
                    text: '是',
                    // cssClass: 'width: 40%',
                    handler: () => {
                        this.processingFailure(1, alarm);
                    }
                }, {
                    text: '不是',
                    // cssClass: 'width: 30%',
                    handler: () => {
                        this.processingFailure(0, alarm);
                    }
                }
            ]
        });

        await alert.present();
    }

    processingFailure(real, alarm) {
        const req = {
            troubleLogNo: this.displayArea === 'alarm' ? alarm.alarmLogNo : alarm.troubleLogNo,
            disposeState: 1,
            isReal: real === 1 ? 1 : 0
        };
        this.api.troubleLog.processingFailure([req, (data) => {
            if (data && data.code === 1) {
                this.api.presentMsgToast(data.message);
            } else {
                this.api.presentMsgToast(data.message);
            }
            this.refresh();
        }]);
    }

    getStartTime(interval) {
        const now = new Date;
        const year = now.getFullYear();
        const month = now.getMonth() - interval;
        const day = now.getDate();
        const time = new Date(year, month, day, 0, 0, 0);
        return time;
    }

    parseTime(time, flg) {
        const year = time.slice(0, 4);
        const month = parseInt(time.slice(5, 7), 10);
        let updateTime = 0;
        if (flg === 'start') {
            updateTime = new Date( year, month - 1, 1, 0, 0, 0).valueOf();
        } else {
            updateTime = new Date( year, month, 0, 23, 59, 59).valueOf();
        }
        return updateTime;
    }

    refresh() {
        this.getTroubleList();
        this.getAlarmList();
    }

    wait(time) {
        return new Promise(resolve => {
            setTimeout(() => {
                resolve();
            }, time);
        });
    }
}
